==> jc-1.4.0.tar.gz: soot/SootResolver.h <==
// public class soot.SootResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b4f2fa22d2f10a73 soot_SootResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_SootResolver_H_
#define _JC_soot_SootResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_Set$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Type$object;
struct _jc_soot_javaToJimple_InitialResolver$object;

// Typedefs
typedef struct _jc_soot_SootResolver$sub_refs	_jc_soot_SootResolver$sub_refs;
typedef struct _jc_soot_SootResolver$sub_nonrefs	_jc_soot_SootResolver$sub_nonrefs;
typedef struct _jc_soot_SootResolver$refs	_jc_soot_SootResolver$refs;
typedef struct _jc_soot_SootResolver$nonrefs	_jc_soot_SootResolver$nonrefs;
typedef struct _jc_soot_SootResolver$object	_jc_soot_SootResolver$object;

typedef const struct _jc_soot_SootResolver$vmethods	_jc_soot_SootResolver$vmethods;
typedef const struct _jc_soot_SootResolver$vtable	_jc_soot_SootResolver$vtable;
typedef const struct _jc_soot_SootResolver$vtype	_jc_soot_SootResolver$vtype;

// Constructors
extern void _jc_soot_SootResolver$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_SootResolver$object *);

// Virtual methods
extern void _jc_soot_SootResolver$method$assertResolvedClass$2803f63818d512a5(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_SootResolver$method$assertResolvedClassForType$c94383438911b4d8(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_soot_Type$object *);
extern struct _jc_soot_SootClass$object *_jc_soot_SootResolver$method$getResolvedClass$4e30830866f81476(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_soot_SootClass$object *_jc_soot_SootResolver$method$resolveClassAndSupportClasses$6bb947ad04a378f1(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_SootResolver$method_info$assertResolvedClass$2803f63818d512a5;
extern _jc_method _jc_soot_SootResolver$method_info$assertResolvedClassForType$c94383438911b4d8;
extern _jc_method _jc_soot_SootResolver$method_info$getResolvedClass$4e30830866f81476;
extern _jc_method _jc_soot_SootResolver$method_info$resolveClassAndSupportClasses$6bb947ad04a378f1;

// Virtual methods structure
struct _jc_soot_SootResolver$vmethods {
	void	(*assertResolvedClass$2803f63818d512a5)(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *);
	void	(*assertResolvedClassForType$c94383438911b4d8)(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_soot_Type$object *);
	struct _jc_soot_SootClass$object	*(*getResolvedClass$4e30830866f81476)(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_soot_SootClass$object	*(*resolveClassAndSupportClasses$6bb947ad04a378f1)(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_SootResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_SootResolver$vmethods	soot_SootResolver;
};

// Vtype
struct _jc_soot_SootResolver$vtype {
	_jc_type			type;
	_jc_soot_SootResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_SootResolver$sub_refs {
	struct _jc_object	*markedClasses;
	struct _jc_java_util_LinkedList$object	*classesToResolve;
	struct _jc_soot_javaToJimple_InitialResolver$object	*initSourceResolver;
};

// Reference instance fields (object)
struct _jc_soot_SootResolver$refs {
    _jc_soot_SootResolver$sub_refs	soot_SootResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_SootResolver$sub_nonrefs {
	jboolean	mIsResolving;
};

// Non-reference instance fields (object)
struct _jc_soot_SootResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_SootResolver$sub_nonrefs	soot_SootResolver;
};

// Object instance structure
struct _jc_soot_SootResolver$object {
	_jc_soot_SootResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_SootResolver$vtype	*vtype;
	_jc_soot_SootResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_SootResolver$vtype _jc_soot_SootResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_SootResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_SootResolver$class_object;

#endif	/* _JC_soot_SootResolver_H_ */

==> jc-1.4.6.tar.gz: soot/SootResolver.h <==
// public class soot.SootResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b4f2fa22d2f10a73 soot_SootResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_SootResolver_H_
#define _JC_soot_SootResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_Set$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_Type$object;
struct _jc_soot_javaToJimple_InitialResolver$object;

// Typedefs
typedef struct _jc_soot_SootResolver$sub_refs	_jc_soot_SootResolver$sub_refs;
typedef struct _jc_soot_SootResolver$sub_nonrefs	_jc_soot_SootResolver$sub_nonrefs;
typedef struct _jc_soot_SootResolver$refs	_jc_soot_SootResolver$refs;
typedef struct _jc_soot_SootResolver$nonrefs	_jc_soot_SootResolver$nonrefs;
typedef struct _jc_soot_SootResolver$object	_jc_soot_SootResolver$object;

typedef const struct _jc_soot_SootResolver$vmethods	_jc_soot_SootResolver$vmethods;
typedef const struct _jc_soot_SootResolver$vtable	_jc_soot_SootResolver$vtable;
typedef const struct _jc_soot_SootResolver$vtype	_jc_soot_SootResolver$vtype;

// Constructors
extern void _jc_soot_SootResolver$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_SootResolver$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_SootResolver$method$assertResolvedClass$2803f63818d512a5(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_SootResolver$method$assertResolvedClassForType$c94383438911b4d8(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootClass$object *_jc_soot_SootResolver$method$getResolvedClass$4e30830866f81476(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootClass$object *_jc_soot_SootResolver$method$resolveClassAndSupportClasses$6bb947ad04a378f1(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_SootResolver$method_info$assertResolvedClass$2803f63818d512a5;
extern _jc_method _jc_soot_SootResolver$method_info$assertResolvedClassForType$c94383438911b4d8;
extern _jc_method _jc_soot_SootResolver$method_info$getResolvedClass$4e30830866f81476;
extern _jc_method _jc_soot_SootResolver$method_info$resolveClassAndSupportClasses$6bb947ad04a378f1;

// Virtual methods structure
struct _jc_soot_SootResolver$vmethods {
	void	(*assertResolvedClass$2803f63818d512a5)(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*assertResolvedClassForType$c94383438911b4d8)(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootClass$object	*(*getResolvedClass$4e30830866f81476)(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootClass$object	*(*resolveClassAndSupportClasses$6bb947ad04a378f1)(_jc_env *, struct _jc_soot_SootResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_SootResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_SootResolver$vmethods	soot_SootResolver;
};

// Vtype
struct _jc_soot_SootResolver$vtype {
	_jc_type			type;
	_jc_soot_SootResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_SootResolver$sub_refs {
	struct _jc_object	*markedClasses;
	struct _jc_java_util_LinkedList$object	*classesToResolve;
	struct _jc_soot_javaToJimple_InitialResolver$object	*initSourceResolver;
};

// Reference instance fields (object)
struct _jc_soot_SootResolver$refs {
    _jc_soot_SootResolver$sub_refs	soot_SootResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_SootResolver$sub_nonrefs {
	jboolean	mIsResolving;
};

// Non-reference instance fields (object)
struct _jc_soot_SootResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_SootResolver$sub_nonrefs	soot_SootResolver;
};

// Object instance structure
struct _jc_soot_SootResolver$object {
	_jc_soot_SootResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_SootResolver$vtype	*vtype;
	_jc_soot_SootResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_SootResolver$vtype _jc_soot_SootResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_SootResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_SootResolver$class_object;

#endif	/* _JC_soot_SootResolver_H_ */
